pub(crate) enum QueriesOutput {
ToFiles {
file_base_path: PathBuf,
},
ToFolders {
reason: Option<String>,
folder_base_path: PathBuf,
},
}Variants
ToFiles
Fields
ToFolders
Fields
reason: Option<String>The reason put into the benchmarking job template. By
default, takes the name of the folder in which the
template is created (i.e. of folder_base_path after
appending the cluster id).
folder_base_path: PathBufWrite queries files one to newly created folders each,
with .$n appended to the path, where $n is the number
of the cluster, as queries.ndjson files. Also creates a
symlink ignore_queries_for_checksum_regex.txt -> ../queries/ignore_queries_for_checksum_regex.txt, and a
file job-template.json5 that can be used with
evobench insert-file to run a job with that queries
file. There is also one dir with .unclustered appended,
that contains queries that did not cluster with any other
query (only if that set is not empty).
Implementations
Sourceimpl QueriesOutput
impl QueriesOutput
pub(crate) fn write_queries<'a>( &self, extension: Option<String>, queries: &mut dyn ExactSizeIterator<Item = &'a Arc<str>>, ) -> Result<()>